Class: Aws::AlexaForBusiness::Types::SendAnnouncementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-alexaforbusiness/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

The unique, user-specified identifier for the request that ensures idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.



4298
4299
4300
4301
4302
4303
4304
4305
# File 'lib/aws-sdk-alexaforbusiness/types.rb', line 4298

class SendAnnouncementRequest < Struct.new(
  :room_filters,
  :content,
  :time_to_live_in_seconds,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#contentTypes::Content

The announcement content. This can contain only one of the three possible announcement types (text, SSML or audio).



4298
4299
4300
4301
4302
4303
4304
4305
# File 'lib/aws-sdk-alexaforbusiness/types.rb', line 4298

class SendAnnouncementRequest < Struct.new(
  :room_filters,
  :content,
  :time_to_live_in_seconds,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#room_filtersArray<Types::Filter>

The filters to use to send an announcement to a specified list of rooms. The supported filter keys are RoomName, ProfileName, RoomArn, and ProfileArn. To send to all rooms, specify an empty RoomFilters list.



4298
4299
4300
4301
4302
4303
4304
4305
# File 'lib/aws-sdk-alexaforbusiness/types.rb', line 4298

class SendAnnouncementRequest < Struct.new(
  :room_filters,
  :content,
  :time_to_live_in_seconds,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#time_to_live_in_secondsInteger

The time to live for an announcement. Default is 300. If delivery doesn't occur within this time, the announcement is not delivered.



4298
4299
4300
4301
4302
4303
4304
4305
# File 'lib/aws-sdk-alexaforbusiness/types.rb', line 4298

class SendAnnouncementRequest < Struct.new(
  :room_filters,
  :content,
  :time_to_live_in_seconds,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end